Chapter 3: Pipelines
====================

In chapter 3, we introduce lens modeling *Pipelines* that fit a strong lens using a sequence of non-linear searches
which each fit a different lens model.

The chapter contains the following tutorials:

`Tutorial 1: Pipeline Lens and Source <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_3_pipelines/tutorial_1_pipeline_runner.html>`_
- Fitting the lens's light followed by its mass.

`Tutorial 2: Pipeline Two Lens Galaxies <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_3_pipelines/tutorial_2_pipeline_runner.html>`_
- Modeling a strong lens with two lens galaxies.

`Tutorial 3: Pipeline Complex Source <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_3_pipelines/tutorial_3_pipeline_runner.html>`_
- Using multiple light profiles to fit a complex and irregular source.

`Tutorial 4: Setup and SLaM <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_3_pipelines/tutorial_4_setup_and_slam.html>`_
- Template objects and pipelines for fitting lens model is standardized ways.

.. toctree::
   :caption: Tutorials:
   :maxdepth: 1
   :hidden:

   tutorial_1_pipeline_runner
   tutorial_2_pipeline_runner
   tutorial_3_pipeline_runner
   tutorial_4_setup_and_slam